import { Component } from '@angular/core';

@Component({
  selector: 'app-tab1',
  templateUrl: 'tab1.page.html',
  styleUrls: ['tab1.page.scss'],
  standalone: false,
})
export class Tab1Page {
  isDark = false;
  currentTime = this.formatTime(new Date());
  dynamicStats = [
    { value: '12', label: '已探索景点' },
    { value: '7.5h', label: '今日游览时长' },
    { value: '125km', label: '本周旅行里程' }
  ];
  smartRecommendation = '根据您的旅行偏好，推荐参观当地历史博物馆';
  socialFeed = [
    { 
      user: { 
        avatar: 'assets/avatars/avatar1.png', 
        nickname: '旅行达人' 
      }, 
      content: '发现了一个绝美的小众景点！#旅行日记', 
      likes: 24, 
      comments: 8 
    },
    { 
      user: { 
        avatar: 'assets/avatars/avatar2.png', 
        nickname: '背包客' 
      }, 
      content: '第一次独自旅行完成！', 
      likes: 15, 
      comments: 5 
    }
  ];

  // 功能快捷入口配置
  features = [
    {
      title: '酒店',
      description: '查找优质住宿',
      icon: 'assets/icons/hotel.png',
      route: '/hotels'
    },
    {
      title: '民宿',
      description: '特色民宿推荐',
      icon: 'assets/icons/home.png',
      route: '/homestays'
    },
    {
      title: '景点',
      description: '热门景点门票',
      icon: 'assets/icons/landmark.png',
      route: '/attractions'
    },
    {
      title: '领券',
      description: '旅游优惠券',
      icon: 'assets/icons/coupon.png',
      route: '/coupons'
    }
  ];

  constructor() {
    setInterval(() => {
      this.currentTime = this.formatTime(new Date());
    }, 1000);
  }

  private formatTime(date: Date): string {
    return `${date.getHours()}:${date.getMinutes().toString().padStart(2, '0')}`;
  }

  toggleTheme() {
    this.isDark = !this.isDark;
    document.body.classList.toggle('dark', this.isDark);
  }

  startSmartPlan() {
    alert(`开始${this.smartRecommendation}`);
  }

  navigateToFeature(route: string) {
    console.log('导航到:', route);
    // 这里可以添加实际的导航逻辑
    // 例如: this.router.navigate([route]);
  }
}