import { Component } from '@angular/core';
import { AlertController } from '@ionic/angular';

@Component({
  selector: 'app-tab3',
  templateUrl: 'tab3.page.html',
  styleUrls: ['tab3.page.scss'],
  standalone: false,
})
export class Tab3Page {
  isDark = false;
  isLoggedIn = true; // 默认为登录状态，实际应用中应根据用户状态动态设置
  user = {
    id: 'u_123456',
    name: '旅行者',
    avatar: 'assets/avatars/user1.png',
    favorites: 12,
    visits: 8
  };

  constructor(private alertController: AlertController) {}

  toggleTheme() {
    this.isDark = !this.isDark;
    document.body.classList.toggle('dark', this.isDark);
  }

  async login() {
    const alert = await this.alertController.create({
      header: '登录',
      inputs: [
        {
          name: 'username',
          type: 'text',
          placeholder: '用户名'
        },
        {
          name: 'password',
          type: 'password',
          placeholder: '密码'
        }
      ],
      buttons: [
        {
          text: '取消',
          role: 'cancel'
        },
        {
          text: '登录',
          handler: (data) => {
            if (data.username && data.password) {
              // 这里应该添加实际的登录逻辑
              // 模拟登录成功
              this.isLoggedIn = true;
              this.user.name = data.username;
              this.user.avatar = 'assets/avatars/user1.png';
              this.user.favorites = 12;
              this.user.visits = 8;
              
              this.showAlert('登录成功', `欢迎回来，${data.username}！`);
            } else {
              this.showAlert('提示', '请输入用户名和密码');
            }
          }
        }
      ]
    });

    await alert.present();
  }

  async editProfile() {
    const alert = await this.alertController.create({
      header: '编辑资料',
      inputs: [
        {
          name: 'username',
          type: 'text',
          value: this.user.name,
          placeholder: '输入新用户名'
        }
      ],
      buttons: [
        {
          text: '取消',
          role: 'cancel'
        },
        {
          text: '保存',
          handler: (data) => {
            if (data.username) {
              this.user.name = data.username;
              this.showAlert('保存成功', '个人资料已更新');
            }
          }
        }
      ]
    });

    await alert.present();
  }

  showSettings() {
    console.log('打开设置页面');
    // 这里可以添加导航到设置页面的逻辑
    this.showAlert('功能提示', '即将打开设置页面');
  }

  viewFavorites() {
    if (!this.isLoggedIn) {
      this.showLoginPrompt();
      return;
    }
    console.log('查看收藏');
    this.showAlert('功能提示', '即将查看我的收藏');
  }

  viewVisits() {
    if (!this.isLoggedIn) {
      this.showLoginPrompt();
      return;
    }
    console.log('查看足迹');
    this.showAlert('功能提示', '即将查看我的足迹');
  }

  showCoupons() {
    if (!this.isLoggedIn) {
      this.showLoginPrompt();
      return;
    }
    console.log('查看优惠券');
    this.showAlert('功能提示', '即将查看我的优惠券');
  }

  showOrders() {
    if (!this.isLoggedIn) {
      this.showLoginPrompt();
      return;
    }
    console.log('查看订单');
    this.showAlert('功能提示', '即将查看我的订单');
  }

  async logout() {
    const alert = await this.alertController.create({
      header: '确认退出',
      message: '确定要退出登录吗？',
      buttons: [
        {
          text: '取消',
          role: 'cancel'
        },
        {
          text: '退出',
          handler: () => {
            // 这里添加实际的退出登录逻辑
            this.isLoggedIn = false;
            this.user.name = '未登录用户';
            this.user.avatar = 'assets/default-avatar.png';
            this.user.favorites = 0;
            this.user.visits = 0;
            
            this.showAlert('已退出', '您已成功退出登录');
          }
        }
      ]
    });

    await alert.present();
  }

  showPrivacyPolicy() {
    console.log('查看隐私政策');
    this.showAlert('隐私政策', '这里将显示应用的隐私政策内容');
  }

  showTermsOfService() {
    console.log('查看服务条款');
    this.showAlert('服务条款', '这里将显示应用的服务条款内容');
  }

  private async showAlert(header: string, message: string) {
    const alert = await this.alertController.create({
      header,
      message,
      buttons: ['好的']
    });
    await alert.present();
  }

  private showLoginPrompt() {
    this.showAlert('提示', '请先登录后再执行此操作');
  }
}